@@ -21,7 +21,6 @@
  *    Chema Celorio <chema@ximian.com>
  *
  *  Copyright 2001-2003 Ximian, Inc.
- *
  */
 
 #ifndef __GNOME_PRINT_CONFIG_H__
@@ -44,7 +43,7 @@
  * along with this library; see the file COPYING.LIB.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
- *
+*
  * Authors:
  *   Lauris Kaplinski <lauris@helixcode.com>
  *
@@ -132,19 +131,20 @@ typedef struct _GnomePrintConfig GnomePrintConfig;
 #include <glib-object.h>
 #include <libgnomeprint/gnome-print-unit.h>
 
-/*
- * Get default print config objects
- */
+#define GNOME_TYPE_PRINT_CONFIG         (gnome_print_config_get_type ())
+#define GNOME_PRINT_CONFIG(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GNOME_TYPE_PRINT_CONFIG, GnomePrintConfig))
+#define GNOME_IS_PRINT_CONFIG(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNOME_TYPE_PRINT_CONFIG))
 
-#define GNOME_TYPE_PRINT_CONFIG (gnome_print_config_get_type ())
+GType             gnome_print_config_get_type (void);
 
 GnomePrintConfig *gnome_print_config_default (void);
 
-GType gnome_print_config_get_type (void);
-
-GnomePrintConfig *gnome_print_config_ref (GnomePrintConfig *config);
+GnomePrintConfig *gnome_print_config_ref   (GnomePrintConfig *config);
 GnomePrintConfig *gnome_print_config_unref (GnomePrintConfig *config);
-GnomePrintConfig *gnome_print_config_dup (GnomePrintConfig *config);
+GnomePrintConfig *gnome_print_config_dup   (GnomePrintConfig *config);
+
+gchar *           gnome_print_config_to_string (GnomePrintConfig *gpc, guint flags);
+GnomePrintConfig *gnome_print_config_from_string (const gchar *str, guint flags);
 
 /*
  * Get/Set key value pairs
@@ -154,34 +154,24 @@ GnomePrintConfig *gnome_print_config_dup (GnomePrintConfig *config);
  * gnome_print_config_get just returns NULL, if given key does not exist.
  *
  */
-
-guchar  *gnome_print_config_get (GnomePrintConfig *config, const guchar *key);
-gboolean gnome_print_config_set (GnomePrintConfig *config, const guchar *key, const guchar *value);
+guchar  *gnome_print_config_get         (GnomePrintConfig *config, const guchar *key);
+gboolean gnome_print_config_set         (GnomePrintConfig *config, const guchar *key, const guchar *value);
 
 gboolean gnome_print_config_get_boolean (GnomePrintConfig *config, const guchar *key, gboolean *val);
-gboolean gnome_print_config_get_int (GnomePrintConfig *config, const guchar *key, gint *val);
-gboolean gnome_print_config_get_double (GnomePrintConfig *config, const guchar *key, gdouble *val);
-gboolean gnome_print_config_get_length (GnomePrintConfig *config, const guchar *key, gdouble *val, const GnomePrintUnit **unit);
+gboolean gnome_print_config_get_int     (GnomePrintConfig *config, const guchar *key, gint *val);
+gboolean gnome_print_config_get_double  (GnomePrintConfig *config, const guchar *key, gdouble *val);
+gboolean gnome_print_config_get_length  (GnomePrintConfig *config, const guchar *key, gdouble *val, const GnomePrintUnit **unit);
 
 gboolean gnome_print_config_set_boolean (GnomePrintConfig *config, const guchar *key, gboolean val);
-gboolean gnome_print_config_set_int (GnomePrintConfig *config, const guchar *key, gint val);
-gboolean gnome_print_config_set_double (GnomePrintConfig *config, const guchar *key, gdouble val);
-gboolean gnome_print_config_set_length (GnomePrintConfig *config, const guchar *key, gdouble val, const GnomePrintUnit *unit);
-
-/*
- * Saving and loading a GnomePrintConfig
- */
-gchar *           gnome_print_config_to_string (GnomePrintConfig *gpc, guint flags);
-GnomePrintConfig *gnome_print_config_from_string (const gchar *str, guint flags);
+gboolean gnome_print_config_set_int     (GnomePrintConfig *config, const guchar *key, gint val);
+gboolean gnome_print_config_set_double  (GnomePrintConfig *config, const guchar *key, gdouble val);
+gboolean gnome_print_config_set_length  (GnomePrintConfig *config, const guchar *key, gdouble val, const GnomePrintUnit *unit);
 
 /*
  * Debugging
  */
 void gnome_print_config_dump (GnomePrintConfig *gpc);
 
-/*
- * Convenience keys
- */
 
 /*
  * Paper size
@@ -192,6 +182,9 @@ void gnome_print_config_dump (GnomePrintConfig *gpc);
  *
  */
 
+/*
+ * Convenience keys
+ */
 #define GNOME_PRINT_KEY_PAPER_SIZE               "Settings.Output.Media.PhysicalSize" /* Paper name, such as A4 or Letter */
 #define GNOME_PRINT_KEY_PAPER_WIDTH              "Settings.Output.Media.PhysicalSize.Width" /* Arbitrary units - use conversion */
 #define GNOME_PRINT_KEY_PAPER_HEIGHT             "Settings.Output.Media.PhysicalSize.Height" /* Arbitrary units - use conversion */
@@ -236,15 +229,10 @@ void gnome_print_config_dump (GnomePrintConfig *gpc);
 
 /* More handy keys */
 #define GNOME_PRINT_KEY_OUTPUT_FILENAME "Settings.Transport.Backend.FileName" /* Filename used when printing to file. */
-#define GNOME_PRINT_KEY_DOCUMENT_NAME "Settings.Document.Name"                /* The name of the document 'Cash flow 2002', `Grandma cockie recipies' */
+#define GNOME_PRINT_KEY_DOCUMENT_NAME "Settings.Document.Name"                /* The name of the document 'Cash flow 2002', `Grandma cookie recipies' */
 #define GNOME_PRINT_KEY_PREFERED_UNIT "Settings.Document.PreferedUnit"        /* Abbreviation for the preferred unit cm, in,... */
 
 G_END_DECLS
 
-#endif
-
-
-
-
-
+#endif /* __GNOME_PRINT_CONFIG_H__ */
 
