@@ -812,8 +812,11 @@ gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font)
 	gint ret = 0;
 	GSList *l;
 
-	if (ps2->selected_font && (ps2->selected_font->face == gnome_font->face) && (ps2->selected_font->currentsize = gnome_font->size))
+	if ((ps2->selected_font) &&
+	    (ps2->selected_font->face == gnome_font->face) &&
+	    (ps2->selected_font->currentsize == gnome_font->size)) {
 		return 0;
+	}
 
 	face = gnome_font_get_face (gnome_font);
 
